@@ -2,11 +2,11 @@
 """PyAlaCarte is a simple programmer's editor."""
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: PyAlaCarte.py 63480 2010-02-14 05:34:39Z RD $"
-__revision__ = "$Revision: 63480 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
-import wx_py as py
+import editor
 
 import os
 import sys
@@ -20,7 +20,7 @@ class App(wx.App):
 
     def OnInit(self):
         wx.InitAllImageHandlers()
-        self.frame = py.editor.EditorFrame(filename=self.filename)
+        self.frame = editor.EditorFrame(filename=self.filename)
         self.frame.Show()
         self.SetTopWindow(self.frame)
         return True
