@@ -2,11 +2,11 @@
 """PyAlaMode is a programmer's editor."""
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: PyAlaMode.py 26212 2004-03-15 13:42:37Z PKO $"
-__revision__ = "$Revision: 26212 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
-import wx_py as py
+import editor
 
 import os
 import sys
@@ -20,7 +20,7 @@ class App(wx.App):
 
     def OnInit(self):
         wx.InitAllImageHandlers()
-        self.frame = py.editor.EditorNotebookFrame(filename=self.filename)
+        self.frame = editor.EditorNotebookFrame(filename=self.filename)
         self.frame.Show()
         self.SetTopWindow(self.frame)
         return True
