@@ -9,8 +9,8 @@ import __main__
 original = __main__.__dict__.keys()
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: PyCrust.py 63480 2010-02-14 05:34:39Z RD $"
-__revision__ = "$Revision: 63480 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
 
@@ -20,7 +20,7 @@ class App(wx.App):
     def OnInit(self):
         import os
         import wx
-        import wx_py as py
+        import crust
         
         self.SetAppName("pycrust")
         confDir = wx.StandardPaths.Get().GetUserDataDir()
@@ -30,7 +30,7 @@ class App(wx.App):
         self.config = wx.FileConfig(localFilename=fileName)
         self.config.SetRecordDefaults(True)
         
-        self.frame = py.crust.CrustFrame(config=self.config, dataDir=confDir)
+        self.frame = crust.CrustFrame(config=self.config, dataDir=confDir)
 ##        self.frame.startupFileName = os.path.join(confDir,'pycrust_startup')
 ##        self.frame.historyFileName = os.path.join(confDir,'pycrust_history')
         self.frame.Show()
@@ -44,7 +44,7 @@ pycrust script that wxPython installs:
 
     #!/usr/bin/env python
 
-    from wx_py.PyCrust import main
+    from wx.py.PyCrust import main
     main()
 '''
 
