@@ -3,18 +3,18 @@
 additional runtime-tools, such as PyCrust."""
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: PyWrap.py 63480 2010-02-14 05:34:39Z RD $"
-__revision__ = "$Revision: 63480 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
-import wx_py as py
+import crust
 
 import os
 import sys
 
 def wrap(app):
     wx.InitAllImageHandlers()
-    frame = py.crust.CrustFrame()
+    frame = crust.CrustFrame()
     frame.SetSize((750, 525))
     frame.Show(True)
     frame.shell.interp.locals['app'] = app
