@@ -1,8 +1,8 @@
 """PyAlaCarte and PyAlaMode editors."""
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: editor.py 60100 2009-04-12 02:56:29Z RD $"
-__revision__ = "$Revision: 60100 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
 
@@ -827,12 +827,81 @@ def directory(parent=None, message='Choose a directory', path='', style=0,
     dialog.Destroy()
     return result
 
+class SaveCancelDialog(wx.Dialog):
+    def __init__(
+            self, parent, id=-1, message=wx.EmptyString, title=wx.EmptyString, pos=wx.DefaultPosition,
+            size=wx.DefaultSize, style=wx.DEFAULT_DIALOG_STYLE,
+            name=wx.DialogNameStr, useMetal=False,
+            ):
+
+        wx.Dialog.__init__(self,parent, id, title, pos, size, style, name)
+        
+        # This extra style can be set after the UI object has been created.
+        if 'wxMac' in wx.PlatformInfo and useMetal:
+            self.SetExtraStyle(wx.DIALOG_EX_METAL)
+        
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        
+        lblsizer = wx.BoxSizer(wx.HORIZONTAL)
+        label = wx.StaticText(self, -1, message)
+        
+        bmp = wx.ArtProvider.GetBitmap(wx.ART_QUESTION,size=(48,48))
+        stabmp = wx.StaticBitmap(self, wx.NewId(), bmp, wx.DefaultPosition, bmp.GetSize(), wx.NO_BORDER)
+        lblsizer.Add(stabmp, 0,wx.EXPAND | wx.LEFT, 12)
+        lblsizer.Add(label, 1, wx.EXPAND | wx.ALL, 12)
+        sizer.Add(lblsizer, 0, wx.LEFT|wx.ALL, 5)
+        
+        btnsizer = wx.BoxSizer(wx.HORIZONTAL)
+        
+        self.DontSaveButton = wx.Button(self,-1,label="Don't Save")
+        self.SaveButton = wx.Button(self,-1,label='Save')
+        self.CancelButton = wx.Button(self,wx.ID_CANCEL)
+        
+        self.DontSaveButton.Bind(wx.EVT_BUTTON,self.DontSave)
+        self.SaveButton.Bind(wx.EVT_BUTTON,self.Save)
+        self.Bind(wx.EVT_CHAR_HOOK,self.OnKeyDown)
+        
+        btnsizer.Add(self.DontSaveButton,wx.ALL|wx.EXPAND,5)
+        btnsizer.Add(self.SaveButton,wx.ALL|wx.EXPAND,5)
+        btnsizer.Add(self.CancelButton,wx.ALL|wx.EXPAND,5)
+        
+        sizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5)
+        
+        self.DontSaveButton.SetDefault()
+        self.DontSaveButton.SetFocus()
+        
+        self.SetSizer(sizer)
+        #self.SetFocus()
+        sizer.Fit(self)
+    def DontSave(self,event):
+        self.EndModal(wx.ID_NO)
+    def Save(self,event):
+        self.EndModal(wx.ID_YES)
+    def OnKeyDown(self,event):
+        key = event.GetKeyCode()
+        # For some reason, the default behavior on Linux
+        # Doesn't allow arrow navigation...
+        # Manually add it back here:
+        focus = wx.Window.FindFocus()
+        
+        if key == wx.WXK_RIGHT:
+            if focus == self.DontSaveButton:  self.SaveButton.SetFocus()
+            elif focus == self.SaveButton:    self.CancelButton.SetFocus()
+            elif focus == self.CancelButton:  self.DontSaveButton.SetFocus()
+        elif key == wx.WXK_LEFT:
+            if focus == self.DontSaveButton:  self.CancelButton.SetFocus()
+            elif focus == self.SaveButton:    self.DontSaveButton.SetFocus()
+            elif focus == self.CancelButton:  self.SaveButton.SetFocus()
+        else:
+            event.Skip()
 
 def messageDialog(parent=None, message='', title='Message box',
-                  style=wx.YES_NO | wx.CANCEL | wx.CENTRE | wx.ICON_QUESTION,
+                  #style=wx.YES_NO | wx.CANCEL | wx.CENTRE | wx.ICON_QUESTION,
+                  style=wx.DEFAULT_DIALOG_STYLE | wx.CENTRE,
                   pos=wx.DefaultPosition):
     """Message dialog wrapper function."""
-    dialog = wx.MessageDialog(parent, message, title, style, pos)
+    #dialog = wx.MessageDialog(parent, message, title, style, pos)
+    dialog = SaveCancelDialog(parent=parent, message=message, title=title, pos=pos, style=style)
     result = DialogResults(dialog.ShowModal())
     dialog.Destroy()
     return result
