@@ -1,8 +1,8 @@
 """Base frame with menu."""
 
 __author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
-__cvsid__ = "$Id: frame.py 63480 2010-02-14 05:34:39Z RD $"
-__revision__ = "$Revision: 63480 $"[11:-2]
+__cvsid__ = "$Id$"
+__revision__ = "$Revision$"[11:-2]
 
 import wx
 import os
@@ -172,7 +172,7 @@ class Frame(wx.Frame):
             m.Append(ID_SHOWTOOLS,
                      'Show &Tools\tF4',
                      'Show the filling and other tools', wx.ITEM_CHECK)
-        if self.shellName==['PySlices','SymPySlices']:
+        if self.shellName in ['PySlices','SymPySlices']:
             m.Append(ID_HIDEFOLDINGMARGIN,
                                 '&Hide Folding Margin',
                                 'Hide Folding Margin', wx.ITEM_CHECK)
@@ -788,7 +788,7 @@ class ShellFrameMixin:
         import  wx.lib.dialogs
         title = 'Help on key bindings'
         
-        text = wx_py.shell.HELP_TEXT
+        text = wx.py.shell.HELP_TEXT
 
         dlg = wx.lib.dialogs.ScrolledMessageDialog(self, text, title,
                                                    size = ((700, 540)))
@@ -860,7 +860,7 @@ class ShellFrameMixin:
                 f.close()
             except:
                 d = wx.MessageDialog(self, "Error saving history file.",
-                                     "Error", wx.ICON_EXCLAMATION)
+                                     "Error", wx.ICON_EXCLAMATION|wx.OK)
                 d.ShowModal()
                 d.Destroy()
                 raise
@@ -878,7 +878,7 @@ class ShellFrameMixin:
                                     history=self.shell.history)
                 except:
                     d = wx.MessageDialog(self, "Error loading history file.",
-                                         "Error", wx.ICON_EXCLAMATION)
+                                         "Error", wx.ICON_EXCLAMATION|wx.OK)
                     d.ShowModal()
                     d.Destroy()
 
@@ -937,7 +937,7 @@ class ShellFrameMixin:
                 f.close()
             except:
                 d = wx.MessageDialog(self, "Error saving startup file.",
-                                     "Error", wx.ICON_EXCLAMATION)
+                                     "Error", wx.ICON_EXCLAMATION|wx.OK)
                 d.ShowModal()
                 d.Destroy()
 
